==> OpenID-1.0.0.tar.gz: OpenID/action.admin_updateproviders.php <==
<?php

/*
 *      Copyright 2010 Henrik Lennartsson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */


if( !isset($gCms) ) exit;

global $gCms;
$db =& $gCms->GetDB();

$this->SetPreference('enable_provider_google', (int) $_POST['input_provider_google']);
$this->SetPreference('enable_provider_yahoo', (int) $_POST['input_provider_yahoo']);
$this->SetPreference('enable_provider_aol', (int) $_POST['input_provider_aol']);
$this->SetPreference('enable_provider_myopenid', (int) $_POST['input_provider_myopenid']);
$this->SetPreference('enable_provider_myspace', (int) $_POST['input_provider_myspace']);
$this->SetPreference('enable_provider_flickr', (int) $_POST['input_provider_flickr']);
$this->SetPreference('enable_provider_facebook', (int) $_POST['input_provider_facebook']);
$this->SetPreference('enable_provider_technorati', (int) $_POST['input_provider_technorati']);
$this->SetPreference('enable_provider_wordpress', (int) $_POST['input_provider_wordpress']);
$this->SetPreference('enable_provider_blogger', (int) $_POST['input_provider_blogger']);
$this->SetPreference('enable_provider_livejournal', (int) $_POST['input_provider_livejournal']);
$this->SetPreference('enable_provider_claimid', (int) $_POST['input_provider_claimid']);
$this->SetPreference('enable_provider_vidoop', (int) $_POST['input_provider_vidoop']);
$this->SetPreference('enable_provider_verisign', (int) $_POST['input_provider_verisign']);
include(dirname(__FILE__) . '/action.defaultadmin.php');

?>

==> OpenID-1.3.0.tar.gz: OpenID/action.admin_updateproviders.php <==
<?php

/*
 *      Copyright 2010 Henrik Lennartsson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */


if( !isset($gCms) ) exit;

global $gCms;
$db =& $gCms->GetDB();

$this->SetPreference('enable_provider_google', (int) $_POST['input_provider_google']);
$this->SetPreference('enable_provider_yahoo', (int) $_POST['input_provider_yahoo']);
$this->SetPreference('enable_provider_aol', (int) $_POST['input_provider_aol']);
$this->SetPreference('enable_provider_myopenid', (int) $_POST['input_provider_myopenid']);
$this->SetPreference('enable_provider_myspace', (int) $_POST['input_provider_myspace']);
$this->SetPreference('enable_provider_flickr', (int) $_POST['input_provider_flickr']);
$this->SetPreference('enable_provider_facebook', (int) $_POST['input_provider_facebook']);
$this->SetPreference('enable_provider_twitter', (int) $_POST['input_provider_twitter']);
$this->SetPreference('enable_provider_twitter_small', (int) $_POST['input_provider_twitter_small']);
$this->SetPreference('enable_provider_technorati', (int) $_POST['input_provider_technorati']);
$this->SetPreference('enable_provider_wordpress', (int) $_POST['input_provider_wordpress']);
$this->SetPreference('enable_provider_blogger', (int) $_POST['input_provider_blogger']);
$this->SetPreference('enable_provider_livejournal', (int) $_POST['input_provider_livejournal']);
$this->SetPreference('enable_provider_claimid', (int) $_POST['input_provider_claimid']);
$this->SetPreference('enable_provider_vidoop', (int) $_POST['input_provider_vidoop']);
$this->SetPreference('enable_provider_verisign', (int) $_POST['input_provider_verisign']);
include(dirname(__FILE__) . '/action.defaultadmin.php');

?>
